@@ -107,6 +107,7 @@ void obt_prop_startup(void)
     CREATE_(NET_WM_ICON_GEOMETRY);
     CREATE_(NET_WM_PID);
     CREATE_(NET_WM_ALLOWED_ACTIONS);
+    CREATE_(NET_WM_WINDOW_OPACITY);
     CREATE_(NET_WM_USER_TIME);
 /*  CREATE_(NET_WM_USER_TIME_WINDOW); */
     CREATE_(KDE_NET_WM_FRAME_STRUT);
@@ -196,6 +197,8 @@ void obt_prop_startup(void)
     CREATE_(OB_APP_TITLE);
     CREATE_(OB_APP_NAME);
     CREATE_(OB_APP_CLASS);
+    CREATE_(OB_APP_GROUP_NAME);
+    CREATE_(OB_APP_GROUP_CLASS);
     CREATE_(OB_APP_TYPE);
 }
 
@@ -311,6 +314,7 @@ static gboolean get_text_property(Window win, Atom prop,
         return tprop->encoding == OBT_PROP_ATOM(UTF8_STRING);
     default:
         g_assert_not_reached();
+        return FALSE;
     }
 }
 
