@@ -9,7 +9,6 @@ void action_all_startup(void)
     action_reconfigure_startup();
     action_exit_startup();
     action_restart_startup();
-    action_session_startup();
     action_cyclewindows_startup();
     action_breakchroot_startup();
     action_close_startup();
@@ -31,12 +30,15 @@ void action_all_startup(void)
     action_resize_startup();
     action_decorations_startup();
     action_desktop_startup();
+    action_dock_startup();
     action_resizerelative_startup();
     action_addremovedesktop_startup();
     action_dockautohide_startup();
     action_layer_startup();
     action_movetoedge_startup();
     action_growtoedge_startup();
+    action_if_startup();
     action_focustobottom_startup();
+    /* 3.4-compatibility */
     action_shadelowerraise_startup();
 }
