@@ -31,13 +31,16 @@ void action_directionalwindows_startup(void);
 void action_resize_startup(void);
 void action_decorations_startup(void);
 void action_desktop_startup(void);
+void action_dock_startup(void);
 void action_resizerelative_startup(void);
 void action_addremovedesktop_startup(void);
 void action_dockautohide_startup(void);
 void action_layer_startup(void);
 void action_movetoedge_startup(void);
 void action_growtoedge_startup(void);
+void action_if_startup(void);
 void action_focustobottom_startup(void);
+/* 3.4-compatibility */
 void action_shadelowerraise_startup(void);
 
 #endif
