@@ -54,9 +54,8 @@ static gboolean desk_menu_update(ObMenuFrame *frame, gpointer data)
 
     for (it = focus_order; it; it = g_list_next(it)) {
         ObClient *c = it->data;
-        if (client_normal(c) && (!c->skip_taskbar || c->iconic) &&
-            (c->desktop == d->desktop || c->desktop == DESKTOP_ALL))
-        {
+        if (focus_valid_target(c, d->desktop,
+                               TRUE, TRUE, FALSE, TRUE, FALSE, FALSE, FALSE)) {
             ObMenuEntry *e;
 
             empty = FALSE;
@@ -70,7 +69,7 @@ static gboolean desk_menu_update(ObMenuFrame *frame, gpointer data)
                 e = menu_add_normal(menu, d->desktop, c->title, NULL, FALSE);
             }
 
-            if (config_menu_client_list_icons) {
+            if (config_menu_show_icons) {
                 e->data.normal.icon = client_icon(c);
                 RrImageRef(e->data.normal.icon);
                 e->data.normal.icon_alpha = c->iconic ? OB_ICONIC_ALPHA : 0xff;
@@ -101,10 +100,12 @@ static void desk_menu_execute(ObMenuEntry *self, ObMenuFrame *f,
 {
     ObClient *t = self->data.normal.data;
     if (t) { /* it's set to NULL if its destroyed */
-        client_activate(t, TRUE, FALSE, TRUE, TRUE, TRUE);
+        gboolean here = state & ShiftMask;
+
+        client_activate(t, TRUE, here, TRUE, TRUE, TRUE);
         /* if the window is omnipresent then we need to go to its
            desktop */
-        if (t->desktop == DESKTOP_ALL)
+        if (!here && t->desktop == DESKTOP_ALL)
             screen_set_desktop(self->id, FALSE);
     }
     else
@@ -115,11 +116,21 @@ static void desk_menu_destroy(ObMenu *menu, gpointer data)
 {
     DesktopData *d = data;
 
-    g_free(d);
+    g_slice_free(DesktopData, d);
 
     desktop_menus = g_slist_remove(desktop_menus, menu);
 }
 
+static void self_cleanup(ObMenu *menu, gpointer data)
+{
+    menu_clear_entries(menu);
+
+    while (desktop_menus) {
+        menu_free(desktop_menus->data);
+        desktop_menus = g_slist_delete_link(desktop_menus, desktop_menus);
+    }
+}
+
 static gboolean self_update(ObMenuFrame *frame, gpointer data)
 {
     ObMenu *menu = frame->menu;
@@ -135,7 +146,7 @@ static gboolean self_update(ObMenuFrame *frame, gpointer data)
     for (i = 0; i < screen_num_desktops; ++i) {
         ObMenu *submenu;
         gchar *name = g_strdup_printf("%s-%u", MENU_NAME, i);
-        DesktopData *ddata = g_new(DesktopData, 1);
+        DesktopData *ddata = g_slice_new(DesktopData);
 
         ddata->desktop = i;
         submenu = menu_new(name, screen_desktop_names[i], FALSE, ddata);
@@ -202,6 +213,7 @@ void client_list_menu_startup(gboolean reconfig)
 
     menu = menu_new(MENU_NAME, _("Desktops"), TRUE, NULL);
     menu_set_update_func(menu, self_update);
+    menu_set_cleanup_func(menu, self_cleanup);
     menu_set_execute_func(menu, self_execute);
 }
 
