@@ -19,6 +19,6 @@
 #ifndef ob__client_menu_h
 #define ob__client_menu_h
 
-void client_menu_startup();
+void client_menu_startup(void);
 
 #endif
