@@ -38,7 +38,8 @@ typedef enum
     OB_PLACE_MONITOR_ANY,
     OB_PLACE_MONITOR_ACTIVE,
     OB_PLACE_MONITOR_MOUSE,
-    OB_PLACE_MONITOR_PRIMARY
+    OB_PLACE_MONITOR_PRIMARY,
+    OB_PLACE_MONITOR_ALL
 } ObPlaceMonitor;
 
 /*! Return TRUE if openbox chose the position for the window, and FALSE if
