@@ -28,33 +28,29 @@ typedef struct _ObWindow         ObWindow;
 typedef struct _ObInternalWindow ObInternalWindow;
 
 typedef enum {
-    Window_Menu,
-    Window_Dock,
-    Window_DockApp, /* used for events but not stacking */
-    Window_Client,
-    Window_Internal,/* used for stacking but not events (except to filter
-                       events on the root window) */
-    Window_Prompt,
-} Window_InternalType;
+    OB_WINDOW_CLASS_MENUFRAME,
+    OB_WINDOW_CLASS_DOCK,
+    OB_WINDOW_CLASS_CLIENT,
+    OB_WINDOW_CLASS_INTERNAL,
+    OB_WINDOW_CLASS_PROMPT
+} ObWindowClass;
 
-struct _ObWindow
-{
-    Window_InternalType type;
+/* In order to be an ObWindow, you need to make this struct the top of your
+   struct */
+struct _ObWindow {
+    ObWindowClass type;
 };
 
-/* Wrapper for internal stuff. If its struct matches this then it can be used
-   as an ObWindow */
-typedef struct InternalWindow {
-    Window_InternalType type;
-    Window window;
-} InternalWindow;
-
-#define WINDOW_IS_MENU(win) (((ObWindow*)win)->type == Window_Menu)
-#define WINDOW_IS_DOCK(win) (((ObWindow*)win)->type == Window_Dock)
-#define WINDOW_IS_DOCKAPP(win) (((ObWindow*)win)->type == Window_DockApp)
-#define WINDOW_IS_CLIENT(win) (((ObWindow*)win)->type == Window_Client)
-#define WINDOW_IS_INTERNAL(win) (((ObWindow*)win)->type == Window_Internal)
-#define WINDOW_IS_PROMPT(win) (((ObWindow*)win)->type == Window_Prompt)
+#define WINDOW_IS_MENUFRAME(win) \
+    (((ObWindow*)win)->type == OB_WINDOW_CLASS_MENUFRAME)
+#define WINDOW_IS_DOCK(win) \
+    (((ObWindow*)win)->type == OB_WINDOW_CLASS_DOCK)
+#define WINDOW_IS_CLIENT(win) \
+    (((ObWindow*)win)->type == OB_WINDOW_CLASS_CLIENT)
+#define WINDOW_IS_INTERNAL(win) \
+    (((ObWindow*)win)->type == OB_WINDOW_CLASS_INTERNAL)
+#define WINDOW_IS_PROMPT(win) \
+    (((ObWindow*)win)->type == OB_WINDOW_CLASS_PROMPT)
 
 struct _ObMenu;
 struct _ObDock;
@@ -62,26 +58,36 @@ struct _ObDockApp;
 struct _ObClient;
 struct _ObPrompt;
 
-#define WINDOW_AS_MENU(win) ((struct _ObMenuFrame*)win)
+#define WINDOW_AS_MENUFRAME(win) ((struct _ObMenuFrame*)win)
 #define WINDOW_AS_DOCK(win) ((struct _ObDock*)win)
-#define WINDOW_AS_DOCKAPP(win) ((struct _ObDockApp*)win)
 #define WINDOW_AS_CLIENT(win) ((struct _ObClient*)win)
-#define WINDOW_AS_INTERNAL(win) ((struct InternalWindow*)win)
+#define WINDOW_AS_INTERNAL(win) ((struct _ObInternalWindow*)win)
 #define WINDOW_AS_PROMPT(win) ((struct _ObPrompt*)win)
 
-#define MENU_AS_WINDOW(menu) ((ObWindow*)menu)
+#define MENUFRAME_AS_WINDOW(menu) ((ObWindow*)menu)
 #define DOCK_AS_WINDOW(dock) ((ObWindow*)dock)
-#define DOCKAPP_AS_WINDOW(dockapp) ((ObWindow*)dockapp)
 #define CLIENT_AS_WINDOW(client) ((ObWindow*)client)
 #define INTERNAL_AS_WINDOW(intern) ((ObWindow*)intern)
 #define PROMPT_AS_WINDOW(prompt) ((ObWindow*)prompt)
 
-extern GHashTable *window_map;
-
-void window_startup(gboolean reconfig);
+void window_startup (gboolean reconfig);
 void window_shutdown(gboolean reconfig);
 
-Window window_top(ObWindow *self);
+Window          window_top  (ObWindow *self);
 ObStackingLayer window_layer(ObWindow *self);
 
+ObWindow* window_find  (Window xwin);
+void      window_add   (Window *xwin, ObWindow *win);
+void      window_remove(Window xwin);
+
+/* Internal openbox-owned windows like the alt-tab popup */
+struct _ObInternalWindow {
+    ObWindowClass type;
+    Window window;
+};
+
+void window_manage_all(void);
+void window_manage(Window win);
+void window_unmanage_all(void);
+
 #endif
